@@ -13,6 +13,13 @@ use Data::Dumper;
 This is experimental software for the moment and under active development. I
 hope to have a beta version available soon.
 
+We use it fairly widely in-house, but it doesn't necessarily implement all of the specs.
+
+Email me with anything you need done urgently.
+
+Also: Check out Archive::BagIt::Fast if you are willing to add some extra dependendies to get
+better speed by mmap-ing files.
+
 =head1 NAME
 
 Archive::BagIt - An interface to make and verify bags according to the BagIt standard
@@ -23,7 +30,7 @@ Version 0.03
 
 =cut
 
-our $VERSION = '0.037';
+our $VERSION = '0.038';
 
 
 =head1 SYNOPSIS
@@ -246,7 +253,10 @@ sub _tagmanifest_md5 {
 
 =head2 verify_bag
 
-An interface to verify a bag
+An interface to verify a bag.
+
+You might also want to check Archive::BagIt::Fast to see a more direct way of accessing files (and thus faster).
+
 
 =cut
 
@@ -279,15 +289,16 @@ sub verify_bag {
     foreach my $file (@payload) {
         next if (-d ($file));
         my $local_name = substr($file, length($bagit) + 1);
+        my ($digest);
         unless ($manifest{$local_name}) {
           die ("file found not in manifest: [$local_name]");
         }
-                #my $start_time=time();
-        open(my $fh, "<:mmap", "$bagit/$local_name") or die ("Cannot open $local_name");
-        binmode($fh);
-        my $digest = $digestobj->addfile($fh)->hexdigest;
+        #my $start_time=time();
+        
+        open(my $fh, "<", "$bagit/$local_name") or die ("Cannot open $local_name");
+        $digest = $digestobj->addfile($fh)->hexdigest;
         close($fh);
-                #print "$bagit/$local_name md5 in ".(time()-$start_time)."\n";
+        #print "$bagit/$local_name md5 in ".(time()-$start_time)."\n";
         unless ($digest eq $manifest{$local_name}) {
           if($return_all_errors) {
             $invalids{$local_name} = $digest;
